@@ -1,6 +1,6 @@
 /* -*- C++ -*-
  * File: libraw_internal_funcs.h
- * Copyright 2008-2009 LibRaw LLC (info@libraw.org)
+ * Copyright 2008-2013 LibRaw LLC (info@libraw.org)
  * Created: Sat Mar  14, 2008
 
 LibRaw is free software; you can redistribute it and/or modify
@@ -23,6 +23,13 @@ it under the terms of the one of three licenses as you choose:
 #ifndef LIBRAW_LIBRARY_BUILD
 #error "This file should be used only for libraw library build"
 #else
+    /* WF */
+    void        wf_bayer4_igauss_filter(int radius,void* src_image, int src_imgmode, void* dst_image, int dst_imgmode);
+    void	wf_bayer4_green_blur   (int mode,void* src_image, int src_imgmode, void* dst_image, int dst_imgmode);
+    void        wf_bayer4_block_filter (int* radius_list, void* src_image, int src_imgmode, void* dst_image, int dst_imgmode);
+    double	wf_filter_energy       (int r1_greenmode, int r1, int r2_greenmode, int r2);
+
+
 // inline functions
     ushort      sget2 (uchar *s);
     ushort      get2();
@@ -38,6 +45,7 @@ it under the terms of the one of three licenses as you choose:
     void        canon_600_auto_wb();
     void        canon_600_coeff();
     void        canon_600_load_raw();
+    void        canon_600_correct();
     int         canon_s2is();
     void        parse_ciff (int offset, int length);
     void        ciff_block_1030();
@@ -50,8 +58,7 @@ it under the terms of the one of three licenses as you choose:
     void        ljpeg_end(struct jhead *jh);
     int         ljpeg_diff (ushort *huff); 
     int         ljpeg_diff_new (LibRaw_bit_buffer& bits, LibRaw_byte_buffer* buf,ushort *huff);
-    int         ljpeg_diff_pef (LibRaw_bit_buffer& bits, LibRaw_byte_buffer* buf,ushort *huff);
-//    ushort *    ljpeg_row (int jrow, struct jhead *jh);
+    ushort *    ljpeg_row (int jrow, struct jhead *jh);
     ushort *    ljpeg_row_new (int jrow, struct jhead *jh, LibRaw_bit_buffer& bits,LibRaw_byte_buffer* bytes);
 
     unsigned    ph1_bithuff (int nbits, ushort *huff);
@@ -59,22 +66,24 @@ it under the terms of the one of three licenses as you choose:
 // Canon DSLRs
 void        crw_init_tables (unsigned table, ushort *huff[2]);
     int         canon_has_lowbits();
-    void        canon_compressed_load_raw();
+    void        canon_load_raw();
     void        lossless_jpeg_load_raw();
     void        canon_sraw_load_raw();
 // Adobe DNG
-    void        adobe_copy_pixel (int row, int col, ushort **rp);
-    void        adobe_dng_load_raw_lj();
-    void        adobe_dng_load_raw_nc();
+    void        adobe_copy_pixel_raw (unsigned int row, unsigned int col, ushort **rp);
+    void        adobe_copy_pixel_color (unsigned int row, unsigned int col, ushort **rp);
+    void        lossless_dng_load_raw();
+    void        packed_dng_load_raw();
+    void        lossy_dng_load_raw();
+//void        adobe_dng_load_raw_nc();
 
 // Pentax
     void        pentax_load_raw();
     void        pentax_tree();
 
 // Nikon (and Minolta Z2)
-    void        nikon_compressed_load_raw();
     void        nikon_load_raw();
-    int         nikon_is_compressed();
+//void        nikon_load_raw();
     int         nikon_e995();
     int         nikon_e2100();
     void        nikon_3700();
@@ -82,7 +91,7 @@ void        crw_init_tables (unsigned table, ushort *huff[2]);
     void        nikon_e2100_load_raw();
 
 // Fuji
-    void        fuji_load_raw();
+//void        fuji_load_raw();
     void        parse_fuji (int offset);
 
 // RedCine
@@ -94,9 +103,9 @@ void        crw_init_tables (unsigned table, ushort *huff[2]);
     void        parse_rollei();
 
 // MF backs
-    int         bayer (unsigned row, unsigned col);
+//int         bayer (unsigned row, unsigned col);
+    int         raw(unsigned,unsigned);
     void        phase_one_flat_field (int is_float, int nc);
-    void        phase_one_correct();
     void        phase_one_load_raw();
     unsigned    ph1_bits (int nbits);
     void        phase_one_load_raw_c();
@@ -104,6 +113,7 @@ void        crw_init_tables (unsigned table, ushort *huff[2]);
     void        leaf_hdr_load_raw();
     void        sinar_4shot_load_raw();
     void        imacon_full_load_raw();
+    void        hasselblad_full_load_raw();
     void        packed_load_raw();
     float	find_green(int,int,int,int);
     void        unpacked_load_raw();
@@ -152,8 +162,12 @@ void        crw_init_tables (unsigned table, ushort *huff[2]);
     void        parse_minolta (int base);
 
 // Foveon/Sigma
-    void        foveon_load_camf();
-    void        foveon_load_raw();
+
+    void        foveon_sd_load_raw();
+    void        foveon_dp_load_raw();
+    void        foveon_huff (ushort *huff);
+void        foveon_load_camf();
+
     const char* foveon_camf_param (const char *block, const char *param);
     void *      foveon_camf_matrix (unsigned dim[3], const char *name);
     int         foveon_fixed (void *ptr, int size, const char *name);
@@ -165,6 +179,7 @@ void        crw_init_tables (unsigned table, ushort *huff[2]);
     char *      foveon_gets (int offset, char *str, int len);
     void        parse_foveon();
 
+
 // CAM/RGB
     void        pseudoinverse (double (*in)[3], double (*out)[3], int size);
     void        cam_xyz_coeff (double cam_xyz[4][3]);
